Cursor

Struct Cursor 

pub struct Cursor<T: FromStr + ToString> { /* private fields */ }
A cursor implementation for use with GraphQL, implements async_graphql::connection::CursorType.

The Cursor consists of a prefix and a ID part. The prefix specifies what kind of object it refers to and the ID specifies which specific object it refers to.

let cursor = Cursor::new("Album", 1);

assert_eq!(cursor.encode_cursor(), "QWxidW06MQ=="); // Album:1

Implementations

Source

impl<T> Cursor<T>
where T: FromStr + ToString + Clone,

pub fn new(prefix: &str, value: T) -> Cursor<T>

Create a new Cursor with the given prefix and value.

This can be used by server implementations to create the appropriate cursor.

pub fn into_prefix(self, prefix: &str) -> Result<T, CursorError>

Deconstruct this cursor into the appropriate ID when its prefix matches.

This function can be used by the server to extract the contained ID. It returns Error when the cursor does not have the specified prefix.


let cursor = Cursor::new("MyPrefix", 10);

assert_eq!(cursor.into_prefix("MyPrefix"), Ok(10));
assert_eq!(cursor.into_prefix("OtherPrefix"), Err(CursorError::InvalidIdentifier));